**Example 1: UnReleaseService**



Input: 

```
tccli apigateway UnReleaseService --cli-unfold-argument  \
    --ServiceId service-ody35h5e \
    --EnvironmentName prepub
```

Output: 
```
{
    "Response": {
        "Result": true,
        "RequestId": "42aafae4-3023-4211-a10a-109163118bb0"
    }
}
```

